// openscad

use<dts_screws.scad>

module frustrum1()
{
    rotate_extrude(angle=360,convexity=10,$fn=180)
    {
        translate([1.969,0,0])
        circle(r=1.5,$fn=180);
    }
}

module frontgrip_top()
{
    Hmin = 0.125/2;
    Hmax = 0.75;
    W = 1.05;
    L = 0.7930;
    
    Wside = 0.25;
    yhole = 0.6;
    
    difference()
    {
        union()
        {
            intersection()
            {
                rotate([0,90,0])
                frustrum1();
                translate([-L/2,-W/2,Hmin])
                cube([L,W,Hmax-Hmin]);
            }
            
            translate([-L/2,-W/2-Wside,Hmin])
            cube([L,Wside,Hmax-Hmin]);
            
            translate([-L/2,W/2,Hmin])
            cube([L,Wside,Hmax-Hmin]);
         
            
        }
        
        cs_capscrew([0,yhole,Hmax],size=8,length=Hmax);
        cs_capscrew([0,-yhole,Hmax],size=8,length=Hmax);
    }   
    
}

module frontsupport()
{
   W = 1.05 + 2*0.25;
   L = 0.7930;
    
   H = 0.31;
    
   cube([L,W,H]);
}

module frontgrip_bottom()
{
    Hmin = 0.125;
    Hmax = 0.75;
    W = 1.05;
    L = 0.7930;
    
    Wside = 0.25;
    yhole = 0.6;
    
    difference()
    {
        union()
        {
            intersection()
            {
                rotate([0,90,0])
                frustrum1();
                translate([-L/2,-W/2,Hmin])
                cube([L,W,Hmax-Hmin]);
            }
            
            translate([-L/2,-W/2-Wside,Hmin])
            cube([L,Wside,Hmax-Hmin]);
            
            translate([-L/2,W/2,Hmin])
            cube([L,Wside,Hmax-Hmin]);
         
            
        }
        
        taphole([0,yhole,Hmax],size=8,depth=Hmax);
        taphole([0,-yhole,Hmax],size=8,depth=Hmax);
    }   
    
}

module bottomplate()
{
    L = 6;
    W = 2.25;
    H = 3/8;
    xsh = 0.5;
    ysh = 0.5;
    Lsh = L-0.5;
    
    xtap = 0.75;
    ytap = W/2.0-0.25;
    xcs = 0.25;
    ycs = W/2.0-0.25;
    
    difference()
    {
        union()
        {
            translate([0,-W/2,0])
            cube([L,W,H]);
            
            translate([L/2.0-Lsh/2.0,-ysh/2.0,H])
            cube([Lsh,ysh,xsh]);
        }
        
        cs_capscrew([xcs,ycs,H],size=8,length=H*1.25);
        taphole([xtap,ytap,H],size=8,depth=H*1.25);
        
        cs_capscrew([xcs,-ycs,H],size=8,length=H*1.25);
        taphole([xtap,-ytap,H],size=8,depth=H*1.25);
        
        cs_capscrew([L-xcs,ycs,H],size=8,length=H*1.25);
        taphole([L-xtap,ytap,H],size=8,depth=H*1.25);
        
        cs_capscrew([L-xcs,-ycs,H],size=8,length=H*1.25);
        taphole([L-xtap,-ytap,H],size=8,depth=H*1.25);
    
    }
}

module midholder_bottom()
{
    xc = 2.25/2.0;
    L = 0.5;
    H1 = 0.5;
    
    rc = 3.0;
    yc = sqrt(rc*rc-xc*xc);
    
    xw = 0.50;
    hw = 1.0;
    
    difference()
    {
        union()
        {
            difference()
            {
                translate([0,-xc,0])
                cube([L,2*xc,H1]);
                
                translate([-L,0,yc+H1])
                rotate([0,90,0])
                cylinder(r=rc,h=3*L,$fn=180);
            }
            
            translate([0,xc,0])
            cube([L,xw,hw]);
            
            translate([0,-xc-xw,0])
            cube([L,xw,hw]);
        
        }
     
        taphole([L/2,xc+xw/2,hw],size=8,depth=2*hw);
        taphole([L/2,-xc-xw/2,hw],size=8,depth=2*hw);
        
    }
    
}

module midholder_top()
{
    xc = 2.25/2.0;
    L = 0.5;
    H1 = 0.5;
    
    rc = 3.0;
    yc = sqrt(rc*rc-xc*xc);
    
    xw = 0.50;
    hw = 1.0;
    
    //depthcs = 0.1640+0.005;
    depthcs = hw-(0.1640+0.005);
    dhole = 0.1695+0.03;
    dcap = 0.2700+0.03;
    
    difference()
    {
        union()
        {
            difference()
            {
                translate([0,-xc,0])
                cube([L,2*xc,H1]);
                
                translate([-L,0,yc+H1])
                rotate([0,90,0])
                cylinder(r=rc,h=3*L,$fn=180);
            }
            
            translate([0,xc,0])
            cube([L,xw,hw]);
            
            translate([0,-xc-xw,0])
            cube([L,xw,hw]);
        
        }
        
     
        //taphole([L/2,xc+xw/2,hw],size=8,depth=2*hw);
        //taphole([L/2,-xc-xw/2,hw],size=8,depth=2*hw);
        rotate([180,0,0])
        //cs_countersink([L/2,xc+xw/2,0],size=8,depth=2*hw);
        gen_countersink([L/2,xc+xw/2,0],dcap,depthcs,dhole,2*hw);
        rotate([180,0,0])
        //cs_countersink([L/2,-xc-xw/2,0],size=8,depth=2*hw);
        gen_countersink([L/2,-xc-xw/2,0],dcap,depthcs,dhole,2*hw);
    }
    
}

frontsupport();

//translate([0,0,1.9575+0.5])
//rotate([180,0,0])
//midholder_top();

//midholder_bottom();

//bottomplate();

//frontgrip_top();
//rotate([180,0,0])
//frontgrip_bottom();