// openscad


module gen_screw(xyz0,dcap,hcap,dthread,length)
{
    dx = 0.0001;
    
    translate(xyz0)
    mirror([0,0,1])
    translate([0,0,-dx])
    union()
    {
        cylinder(d=dcap,h=hcap,$fn=180);
        translate([0,0,hcap-dx])
        cylinder(d=dthread,h=length-hcap,$fn=180);
    }
    
}

module gen_hole(xyz0,dhole,depth)
{
    dx = 0.0001;
       
    translate(xyz0)
        translate([0,0,(-depth-dhole*cos(45))+2*dx])
        union()
        {
            cylinder(d1=0,d2=dhole,h=dhole*cos(45),$fn=180);
            translate([0,0,dhole*cos(45)-dx])
            cylinder(d=dhole,h=depth,$fn=180);
        }
    
    
}

module gen_countersink(xyz0,dcap,depthcs,dhole,depth)
{
    dx = 0.0001;
    
    translate(xyz0)
    mirror([0,0,1])
    translate([0,0,-dx])
    union()
    {
        cylinder(d=dcap,h=depthcs,$fn=180);
        translate([0,0,depthcs-dx])
        cylinder(d=dhole,h=depth-depthcs,$fn=180);
    }
}

module cs_capscrew(xyz=[0,0,0],size=8,length=1.0)
{
    //For sizes 4,6,8, and 10 screws
    
    sizeinds = [0,0,0,0,1,0,2,0,3,0,4];
    dthreads = [0.0,0.1120,0.1380,0.1640,0.1900];
    dcaps = [0.0,0.1830,0.2260,0.2700,0.3120];
    hcaps = [0.0,0.1120,0.1380,0.1640,0.1900];
    
    dthread = dthreads[sizeinds[size]];
    dcap = dcaps[sizeinds[size]];
    hcap = hcaps[sizeinds[size]];
    
    
    /*
    if(size==4)
    {
        dthread = 0.1120;
        dcap = 0.1830;
        hcap = 0.1120;
    }
    else if(size==6)
    {
        dthread = 0.1380;
        dcap = 0.2260;
        hcap = 0.1380;        
    }
    else if(size==8)
    {
        dthread = 0.1640;
        dcap = 0.2700;
        hcap = 0.1640;  
    }
    else if(size==10)
    {
        dthread = 0.1900;
        dcap = 0.3120;
        hcap = 0.1900;
    }
    else
    {
        echo("cs_capscrew defined only for sizes 4,6,8,10");
        dthread = 0.0;
        dcap = 0.0;
        hcap = 0.0;
    }
    */
    
    gen_screw(xyz,dcap,hcap,dthread,length);
}

module cs_capscrew_lp(xyz=[0,0,0],size=8,length=1.0)
{
    //For sizes 4,6,8, and 10 screws
    // Low profile head heights
    sizeinds = [0,0,0,0,1,0,2,0,3,0,4];
    dthreads = [0.0,0.1120,0.1380,0.1640,0.1900];
    dcaps = [0.0,0.1830,0.2260,0.2700,0.3120];
    hcaps = [0.0,0.0590,0.0625,0.0781,0.0937];
    
    dthread = dthreads[sizeinds[size]];
    dcap = dcaps[sizeinds[size]];
    hcap = hcaps[sizeinds[size]];
    
    gen_screw(xyz,dcap,hcap,dthread,length);
}

module taphole(xyz=[0,0,0],size=8,depth=1.0)
{
    //For sizes 4-40,6-32,8-32, and 10-24 screws
    
    sizeinds = [0,0,0,0,1,0,2,0,3,0,4];
    dtaps = [0.0,0.0960,0.1160,0.1440,0.1610];
    
    dtap = dtaps[sizeinds[size]];
    
    gen_hole(xyz,dtap,depth);
    
}

module cs_countersink(xyz=[0,0,0],size=8,depth=1.0)
{
    //For sizes 4,6,8, and 10 screws
    
    sizeinds = [0,0,0,0,1,0,2,0,3,0,4];
    dholes = [0.0,0.1160,0.1440,0.1695,0.1960];
    dcaps = [0.0,0.1830,0.2260,0.2700,0.3120];
    hcaps = [0.0,0.1120,0.1380,0.1640,0.1900];
    
    dhole = dholes[sizeinds[size]];
    dcap = dcaps[sizeinds[size]]+0.01;
    hcap = hcaps[sizeinds[size]]+0.005;
    
    gen_countersink(xyz,dcap,hcap,dhole,depth);
    
}

module cs_countersink_lp(xyz=[0,0,0],size=8,depth=1.0)
{
    //For sizes 4,6,8, and 10 screws
    
    sizeinds = [0,0,0,0,1,0,2,0,3,0,4];
    dholes = [0.0,0.1160,0.1440,0.1695,0.1960];
    dcaps = [0.0,0.1830,0.2260,0.2700,0.3120];
    hcaps = [0.0,0.0590,0.0625,0.0781,0.0937];
    
    dhole = dholes[sizeinds[size]];
    dcap = dcaps[sizeinds[size]]+0.01;
    hcap = hcaps[sizeinds[size]]+0.005;
    
    gen_countersink(xyz,dcap,hcap,dhole,depth);
    
}


/*
difference()
{
translate([-0.5,-0.5,-1])
cube([1,1,1]);

gen_countersink([0,0.25,0],0.5,0.25,0.125,1.25);
}

cs_capscrew_lp(xyz=[2.0,0,0],size=6,length=1.0);

cs_countersink(xyz=[0,2.0,0],size=8,depth=0.5);
*/